@@ -3,7 +3,7 @@
  *
  * @brief
  *
- * @copyright BSD License (see doc/LICENSE.md or http://www.libelektra.org)
+ * @copyright BSD License (see LICENSE.md or https://www.libelektra.org)
  */
 
 #include <ctype.h>
@@ -31,8 +31,8 @@
 #define CMAKE_CACHE_FILENAME "CMakeCache.txt"
 #define CMAKE_CACHE_VARNAME "Elektra_SOURCE_DIR"
 #define TEMP_FILENAME "temp"
-#define INVALIDLINK_MESS "%s|%i col 0| warning: invalid link '%s'\n"
-#define HTTPLINK_FORMAT "%s|%i col 0| %s\n"
+#define INVALIDLINK_MESS "%s:%i:0 warning: invalid link '%s'\n"
+#define HTTPLINK_FORMAT "%s:%i:0| %s\n"
 #define HTTPLINK_FILENAME "external-links.txt"
 
 // Link Blacklist: do not convert links with the following starting and ending
@@ -101,7 +101,7 @@ static inline int linkNolink (int old UNUSED, int new)
 	return new == 0 || new == 1;
 }
 
-struct transitionLink genLinkTransitionTable ()
+struct transitionLink genLinkTransitionTable (void)
 {
 	struct transitionLink out = { {
 		// char\state    0  1  2  3  4  5  6(trap)
@@ -135,7 +135,7 @@ static inline int titleIsGoal (int old, int new)
 	return old == 3 && new == 0;
 }
 
-struct transitionTitle genTitleTransitionTable ()
+struct transitionTitle genTitleTransitionTable (void)
 {
 	struct transitionTitle out = { {
 		// char\state    0  1  2  3
@@ -154,7 +154,7 @@ struct transitionTitle genTitleTransitionTable ()
 	return out;
 }
 
-// Maps a given char to a int, used for the transition table
+// Maps a given char to an int, used for the transition table
 static int resolveChar (int c)
 {
 	if (c != '\n' && isblank (c)) return 3;
@@ -219,9 +219,9 @@ static void convertLinks (FILE * input, FILE * output, char * inputFilename, int
 	FILE * httplinks = fopen (HTTPLINK_FILENAME, "a");
 	if (!httplinks)
 	{
-		fprintf (stderr, "WARNING http link file %s cound not be opened\n", HTTPLINK_FILENAME);
+		fprintf (stderr, "WARNING http link file %s could not be opened\n", HTTPLINK_FILENAME);
 	}
-	int lineCount = 0;
+	int lineCount = 1;
 	int c;
 	fpos_t pos;
 	int state = linkStart;
@@ -495,8 +495,8 @@ static void printTarget (FILE * output, char * target, char * inputFilename, int
 					return;
 				}
 			}
+			strcpy (++lastFolderDelimiter, target);
 		}
-		strcpy (++lastFolderDelimiter, target);
 	}
 	else
 	{
