@@ -3,23 +3,24 @@
  *
  * @brief
  *
- * @copyright BSD License (see doc/LICENSE.md or http://www.libelektra.org)
+ * @copyright BSD License (see LICENSE.md or https://www.libelektra.org)
  */
 
 #include <kdb.h>
+#include <kdbmacros.h> // Declares `ELEKTRA_STRINGIFY`
+#include <stdint.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 
 void printError (Key * key);
 void printWarnings (Key * key);
-void removeMetaData (Key * key, const char * searchfor);
 
-int main ()
+int main (void)
 {
 	KeySet * myConfig = ksNew (0, KS_END);
-	Key * key = keyNew ("/sw/MyApp", KEY_CASCADING_NAME, KEY_END);
-	KDB * handle = kdbOpen (key);
+	Key * key = keyNew ("/sw/MyApp", KEY_END);
+	KDB * handle = kdbOpen (NULL, key);
 
 	if (!handle) printError (key);
 
@@ -66,7 +67,9 @@ void printError (Key * key)
 	printf ("Error occurred: %s\n", keyString (keyGetMeta (key, "error/description")));
 
 	/*remove error*/
-	removeMetaData (key, "error");
+	Key * cutpoint = keyNew ("meta:/error", KEY_END);
+	ksDel (ksCut (keyMeta (key), cutpoint));
+	keyDel (cutpoint);
 }
 
 
@@ -79,32 +82,22 @@ void printError (Key * key)
  */
 void printWarnings (Key * key)
 {
-	if (!keyGetMeta (key, "warnings")) return;
-	char * end;
-	int warn_count = strtol (keyString (keyGetMeta (key, "warnings")), &end, 10);
-	if (*end)
+	Key * cutpoint = keyNew ("meta:/warnings", KEY_END);
+	KeySet * warnings = ksCut (keyMeta (key), cutpoint);
+
+	for (elektraCursor i = 1; i < ksGetSize (warnings); ++i)
 	{
-		printf ("strtol error\n");
-		return;
+		Key * cur = ksAtCursor (warnings, i);
+		if (keyIsDirectlyBelow (cutpoint, cur))
+		{
+			Key * lookup = keyNew (keyName (cur), KEY_END);
+			keyAddBaseName (cur, "description");
+			printf ("Warning occurred: %s\n", keyString (ksLookup (warnings, lookup, KDB_O_DEL)));
+		}
 	}
-	int warn_iter = 0;
 
-	char buffer[sizeof ("warnings/#00/description")];
-
-	do
-	{
-		if (warn_iter < 10)
-			sprintf (&buffer[0], "warnings/#0%i/description", warn_iter);
-		else
-			sprintf (&buffer[0], "warnings/#%i/description", warn_iter);
-
-		const Key * warnkey = keyGetMeta (key, buffer);
-		printf ("Warning occurred: %s\n", keyString (warnkey));
-		++warn_iter;
-	} while (warn_iter <= warn_count);
-
-	/*remove all warnings*/
-	removeMetaData (key, "warnings");
+	keyDel (cutpoint);
+	ksDel (warnings);
 }
 
 
