@@ -3,7 +3,7 @@
  *
  * @brief
  *
- * @copyright BSD License (see doc/LICENSE.md or http://www.libelektra.org)
+ * @copyright BSD License (see LICENSE.md or https://www.libelektra.org)
  */
 
 #include <keyset.hpp>
@@ -14,7 +14,7 @@ int main ()
 {
 	using namespace kdb;
 
-	Key k ("user/name/a/very/long\\/name/to\\\\/iterate\\with\\/some\\\\\\/escaping", KEY_END);
+	Key k ("user:/name/a/very/long\\/name/to\\\\/iterate\\with\\/some\\\\\\/escaping", KEY_END);
 
 	std::cout << "begin: " << *k.begin () << std::endl;
 	std::cout << "end: " << *k.end () << std::endl;
