@@ -1,11 +1,13 @@
+//! General methods to access the Key database.
+//! 
+//! For example usage see the [Readme](https://github.com/ElektraInitiative/libelektra/tree/master/src/bindings/rust).
+
 use crate::ReadableKey;
-use crate::{KeySet, StringKey, WriteableKey};
+use crate::{KeySet, StringKey, WriteableKey, CopyOption};
 use std::error::Error;
 use std::fmt::{self, Display, Formatter};
 use std::ptr::NonNull;
 
-/// General methods to access the Key database.
-/// For example usage see [the Readme](https://github.com/ElektraInitiative/libelektra/tree/master/src/bindings/rust).
 #[derive(Debug)]
 pub struct KDB {
     ptr: NonNull<elektra_sys::KDB>,
@@ -23,12 +25,24 @@ impl Drop for KDB {
 
 impl KDB {
     /// Opens the session with the Key database.
-    pub fn open<'a>() -> Result<Self, KDBError<'a>> {
+    pub fn open<'a, C>(contract: C) -> Result<Self, KDBError<'a>>
+        where 
+            C: Into<Option<KeySet>> {
+
         let mut key = StringKey::new_empty();
-        let kdb_ptr = unsafe { elektra_sys::kdbOpen(key.as_ptr()) };
+        let contract_opt = contract.into();
+
+        let kdb_ptr = match contract_opt {
+            Some(mut contract) => {
+                unsafe { elektra_sys::kdbOpen(contract.as_ptr(), key.as_ptr()) }
+            }
+            None => {
+                unsafe { elektra_sys::kdbOpen(std::ptr::null_mut(), key.as_ptr()) }
+            }
+        };
 
         if kdb_ptr.is_null() {
-            Err(KDBError::new(key.duplicate()))
+            Err(KDBError::new(key.duplicate(CopyOption::KEY_CP_ALL)))
         } else {
             Ok(KDB {
                 ptr: NonNull::new(kdb_ptr).unwrap(),
@@ -54,7 +68,7 @@ impl KDB {
         } else if ret_val == 0 {
             Ok(false)
         } else {
-            Err(KDBError::new(key.duplicate()))
+            Err(KDBError::new(key.duplicate(CopyOption::KEY_CP_ALL)))
         }
     }
 
@@ -76,29 +90,10 @@ impl KDB {
         } else if ret_val == 0 {
             Ok(false)
         } else {
-            Err(KDBError::new(key.duplicate()))
+            Err(KDBError::new(key.duplicate(CopyOption::KEY_CP_ALL)))
         }
     }
 
-    /// This method can be used the given KDB handle meets certain clauses, specified in contract.
-    /// The return value is true on success,
-    /// and false if clauses of the contract are unmet.
-    pub fn ensure<'a>(
-        &mut self,
-        keyset: &mut KeySet,
-        key: &mut StringKey<'a>,
-    ) -> Result<bool, KDBError<'a>> {
-        let ret_val =
-            unsafe { elektra_sys::kdbEnsure(self.as_ptr(), keyset.as_ptr(), key.as_ptr()) };
-
-        if ret_val == 0 {
-            Ok(true)
-        } else if ret_val == 1 {
-            Ok(false)
-        } else {
-            Err(KDBError::new(key.duplicate()))
-        }
-    }
     /// Returns the raw pointer of the KDB object.
     /// Should be used with caution. In particular,
     /// the pointer should only be modified with
@@ -468,9 +463,9 @@ mod test {
     use super::*;
     use crate::{KeyBuilder, LookupOption};
 
-    const PARENT_KEY: &str = "user/sw/tests/rust/1/";
-    const KEY_1_NAME: &str = "user/sw/tests/rust/1/key_name";
-    const KEY_2_NAME: &str = "user/sw/tests/rust/1/key_name/2";
+    const PARENT_KEY: &str = "user:/sw/tests/rust/1/";
+    const KEY_1_NAME: &str = "user:/sw/tests/rust/1/key_name";
+    const KEY_2_NAME: &str = "user:/sw/tests/rust/1/key_name/2";
 
     const KEY_1_VALUE: &str = "key_value_1";
     const KEY_2_VALUE: &str = "key_value_2";
@@ -488,7 +483,7 @@ mod test {
 
     fn set_kdb() {
         let mut parent_key = get_parent_key();
-        let mut kdb = KDB::open().unwrap_or_else(|e| panic!("{}", e));
+        let mut kdb = KDB::open(None).unwrap_or_else(|e| panic!("{}", e));
         let mut ks = KeySet::with_capacity(10);
         kdb.get(&mut ks, &mut parent_key)
             .unwrap_or_else(|e| panic!("{}", e));
@@ -512,7 +507,7 @@ mod test {
 
     fn get_kdb() {
         let mut parent_key = get_parent_key();
-        let mut kdb = KDB::open().unwrap_or_else(|e| panic!("{}", e));
+        let mut kdb = KDB::open(None).unwrap_or_else(|e| panic!("{}", e));
         let mut ks = KeySet::with_capacity(2);
         let get_res = kdb
             .get(&mut ks, &mut parent_key)
@@ -522,19 +517,19 @@ mod test {
         let key1_lookup = ks
             .lookup_by_name(KEY_1_NAME, Default::default())
             .unwrap()
-            .duplicate();
+            .duplicate(CopyOption::KEY_CP_ALL);
         assert_eq!(key1_lookup.value(), KEY_1_VALUE);
 
         let key2_lookup = ks
             .lookup_by_name(KEY_2_NAME, Default::default())
             .unwrap()
-            .duplicate();
+            .duplicate(CopyOption::KEY_CP_ALL);
         assert_eq!(key2_lookup.value(), KEY_2_VALUE);
     }
 
     fn remove_test_keys() {
         let mut parent_key = get_parent_key();
-        let mut kdb = KDB::open().unwrap_or_else(|e| panic!("{}", e));
+        let mut kdb = KDB::open(None).unwrap_or_else(|e| panic!("{}", e));
         let mut ks = KeySet::with_capacity(10);
         let get_res = kdb
             .get(&mut ks, &mut parent_key)
