@@ -239,14 +239,17 @@ keyDel(key);
  * must never use the pointer returned by keyName() method to set a new
  * value. Use keySetName() instead.
  *
- * @param key the key object to work with
- * @return a pointer to the keyname which must not be changed.
- * @retval "" when there is no (an empty) keyname
+ * @param key the Key you want to get the name from
+ *
+ * @return a pointer to the Key's name which must not be changed.
+ * @retval "" when Key's name is empty
  * @retval 0 on NULL pointer
+ *
+ * @since 1.0.0
+ * @ingroup keyname
  * @see keyGetNameSize() for the string length
  * @see keyGetName() as alternative to get a copy
  * @see keyUnescapedName to get an unescaped key name
- * @ingroup keyname
  */
 const char * keyName (const Key * key)
 {
@@ -257,19 +260,22 @@ const char * keyName (const Key * key)
 }
 
 /**
- * Bytes needed to store the key name without owner.
+ * Bytes needed to store the Key's name (excluding owner).
  *
- * For an empty key name you need one byte to store the ending NULL.
- * For that reason 1 is returned.
+ * For an empty Key name you need one byte to store the ending NULL.
+ * For that reason, 1 is returned when the name is empty.
  *
- * @param key the key object to work with
- * @return number of bytes needed, including ending NULL, to store key name
- * 	without owner
- * @retval 1 if there is is no key Name
+ * @param key the Key to get the name size from
+ *
+ * @return number of bytes needed, including NULL terminator, to store Key's name
+ * 	(excluding owner)
+ * @retval 1 if Key has no name
  * @retval -1 on NULL pointer
- * @see keyGetName()
- * @see keyGetUnescapedNameSize to get size of unescaped name
+ *
+ * @since 1.0.0
  * @ingroup keyname
+ * @see keyGetName() for getting the Key's name
+ * @see keyGetUnescapedNameSize() for getting the size of the unescaped name
  */
 ssize_t keyGetNameSize (const Key * key)
 {
@@ -280,23 +286,27 @@ ssize_t keyGetNameSize (const Key * key)
 
 
 /**
- * @brief Returns a keyname which is null separated and does not use backslash for escaping
+ * Returns a Key's name, separated by NULL bytes and without backslashes for
+ * escaping
  *
- * Slashes are replaced with null bytes.
- * So cascading keys start with a null byte.
- * Otherwise escaped characters, e.g. non-hierarchy slash, will be unescaped.
+ * Slashes are replaced with NULL bytes.
+ * Therefore unescaped names of cascading Keys start with a NULL byte.
+ * Otherwise escaped characters, e.g. non-hierarchy slashes, will be unescaped.
  *
- * This name is essential if you want to iterate over parts of the key
- * name, want to compare keynames and want to check relations of keys in
- * the hierarchy.
+ * This name is essential if you want to iterate over parts of the Key's
+ * name, compare Key names or check relations of Keys in the hierarchy.
  *
- * @param key the object to work with
+ * @param key the Key whose unescaped name to get
  *
- * @see keyGetUnescapedNameSize()
- * @see keyName() for escaped variant
- * @retval 0 on null pointers
- * @retval "" if no name
  * @return the name in its unescaped form
+ * @retval 0 on NULL pointers
+ * @retval "" if Key's name is empty
+ *
+ * @since 1.0.0
+ * @ingroup keyname
+ * @see keyGetUnescapedName() for getting a copy of the unescaped name
+ * @see keyGetUnescapedNameSize() for getting the size of the unescaped name
+ * @see keyName() for getting the escaped name of the Key
  */
 const void * keyUnescapedName (const Key * key)
 {
@@ -307,14 +317,20 @@ const void * keyUnescapedName (const Key * key)
 
 
 /**
- * @brief return size of unescaped name with embedded and terminating null characters
+ * @brief Returns the size of the Key's unescaped name including embedded and
+ * terminating NULL characters
  *
- * @param key the object to work with
+ * @param key the Key where to get the size of the unescaped name from
  *
- * @see keyUnescapedName()
- * @see keyGetNameSize() for size of escaped variant
- * @retval -1 on null pointer
- * @retval 0 if no name
+ * @return The size of the Key's unescaped name
+ * @retval -1 on NULL pointer
+ * @retval 0 if Key has no name
+ *
+ * @since 1.0.0
+ * @ingroup keyname
+ * @see keyUnescapedName() for getting a pointer to the unescaped name
+ * @see keyGetUnescapedName() for getting a copy of the unescaped name
+ * @see keyGetNameSize() for getting the size of the escaped name
  */
 ssize_t keyGetUnescapedNameSize (const Key * key)
 {
@@ -325,30 +341,40 @@ ssize_t keyGetUnescapedNameSize (const Key * key)
 
 
 /**
- * Get abbreviated key name (without owner name).
+ * Get abbreviated Key name (excluding owner).
  *
  * When there is not enough space to write the name,
  * nothing will be written and -1 will be returned.
  *
- * maxSize is limited to SSIZE_MAX. When this value
- * is exceeded -1 will be returned. The reason for that
- * is that any value higher is just a negative return
- * value passed by accident. Of course elektraMalloc is not
- * as failure tolerant and will try to allocate.
+ * @p maxSize is limited to SSIZE_MAX. When this value
+ * is exceeded, -1 will be returned. The reason for that
+ * is, that any value higher is just a negative return
+ * value passed by accident. elektraMalloc() is not
+ * as failure tolerant and would try to allocate memory
+ * accordingly.
  *
  * @code
 char *getBack = elektraMalloc (keyGetNameSize(key));
 keyGetName(key, getBack, keyGetNameSize(key));
  * @endcode
  *
+ * @param key the Key to get the name from
+ * @param returnedName pre-allocated buffer to write the Key's name
+ * @param maxSize maximum number of bytes that will fit in returnedName,
+ * including the NULL terminator
+ *
  * @return number of bytes written to @p returnedName
- * @retval 1 when only a null was written
- * @retval -1 when keyname is longer then maxSize or 0 or any NULL pointer
- * @param key the key object to work with
- * @param returnedName pre-allocated memory to write the key name
- * @param maxSize maximum number of bytes that will fit in returnedName, including the final NULL
- * @see keyGetNameSize()
+ * @retval 1 when only NULL terminator was written
+ * @retval -1 when Key's name is longer than maxSize or maxSize is 0 or maxSize
+ * is greater than SSIZE_MAX
+ * @retval -1 @p key or @p returnedName is NULL pointer
+ *
+ * @since 1.0.0
  * @ingroup keyname
+ * @see keyGetNameSize() for getting the size of a Key's name
+ * @see keyName() for getting a pointer to a Key's name
+ * @see keyGetBaseName() for getting a Key's base name
+ * @see keyGetNamespace() for getting the namespace of a Key's name
  */
 ssize_t keyGetName (const Key * key, char * returnedName, size_t maxSize)
 {
@@ -377,21 +403,32 @@ ssize_t keyGetName (const Key * key, char * returnedName, size_t maxSize)
 }
 
 /**
- * Copies the unescaped name of a key into provided buffer.
- * We will only copy the full name, if the buffer is to small an error code is returned.
+ * Copies the unescaped name of a Key into @p returnedName.
  *
- * To ensure your buffer is big enough, you can use keyGetUnescapedNameSize() to find the correct size.
+ * It will only copy the whole name. If the buffer is too small,
+ * an error code will be returned.
+ *
+ * To ensure the buffer is big enough, you can use keyGetUnescapedNameSize()
+ * to get the correct size.
  *
  * @param key          the Key to extract the unescaped name from
- * @param returnedName output buffer
- * @param maxSize      maximum bytes that can be copied into @p returnedName
+ * @param returnedName the buffer to write the unescaped name into
+ * @param maxSize      maximum number of bytes that can be copied
+ * into @p returnedName
  *
  * @pre @p key MUST be a valid #Key and `key != NULL`
- * @pre @p returnedName MUST be allocated to be at least @p maxSize bytes big and `returnedName != NULL`
+ * @pre @p returnedName MUST be allocated to be at least @p maxSize bytes big
+ * @pre @p returnedName must not be NULL
  *
- * @retval -1 precondition error
- * @retval -2 the size of the unescaped name is bigger then @p maxSize
- * @returns otherwise, the actual size of the unescaped name, i.e. the number of bytes copied into @p returnedName
+ * @returns the actual size of the Key's unescaped name, i.e. the number of
+ * bytes copied into @p returnedName
+ * @retval -1 Precondition error
+ * @retval -2 the size of the unescaped name is greater than @p maxSize
+ *
+ * @since 1.0.0
+ * @ingroup keyname
+ * @see keyGetUnescapedNameSize() for getting the size of the unescaped name
+ * @see keyGetName() for getting the Key's escaped name
  */
 ssize_t keyGetUnescapedName (const Key * key, char * returnedName, size_t maxSize)
 {
@@ -415,7 +452,7 @@ ssize_t keyGetUnescapedName (const Key * key, char * returnedName, size_t maxSiz
 }
 
 /**
- * Set a new name to a key.
+ * Set a new name to a Key.
  *
  * A valid name is one of the forms:
  * @copydetails doxygenNamespaces
@@ -426,12 +463,12 @@ ssize_t keyGetUnescapedName (const Key * key, char * returnedName, size_t maxSiz
  * See @link keyname key names @endlink for the exact rules.
  *
  * The last form has explicitly set the owner, to let the library
- * know in which user folder to save the key. A owner is a user name.
- * If it is not defined (the second form) current user is used.
+ * know in which user folder to save the Key. A owner is a user name.
+ * If it is not defined (the second form), current user is used.
  *
- * You should always follow the guidelines for key tree structure creation.
+ * You should always follow the guidelines for Key tree structure creation.
  *
- * A private copy of the key name will be stored, and the @p newName
+ * A private copy of the Key name will be stored, and the @p newName
  * parameter can be freed after this call.
  *
  * .., . and / will be handled as in filesystem paths. A valid name will be build
@@ -439,17 +476,19 @@ ssize_t keyGetUnescapedName (const Key * key, char * returnedName, size_t maxSiz
  *
  * On invalid names, NULL or "" the name will be "" afterwards.
  *
+ * @return size of the new Key name in bytes, including NULL terminator
+ * @retval -1 if @p key or @p keyName is NULL or @p keyName is empty or invalid
+ * @retval -1 if Key was inserted to a KeySet before
+ * @retval -1 if Key name is read-only
  *
- * @retval size in bytes of this new key name including ending NULL
- * @retval 0 if newName is an empty string or a NULL pointer (name will be empty afterwards)
- * @retval -1 if newName is invalid (name will be empty afterwards)
- * @retval -1 if key was inserted to a keyset before
- * @param key the key object to work with
- * @param newName the new key name
- * @see keyNew()
- * @see keyGetName(), keyName()
- * @see keySetBaseName(), keyAddBaseName() to manipulate a name
+ * @param key the Key whose name to set
+ * @param newName the new name for the Key
+ *
+ * @since 1.0.0
  * @ingroup keyname
+ * @see keyGetName() for getting a copy of the Key's name
+ * @see keyName() for getting a pointer to the Key's name
+ * @see keySetBaseName(), keyAddBaseName() for manipulating the base name
  */
 ssize_t keySetName (Key * key, const char * newName)
 {
@@ -487,7 +526,7 @@ ssize_t keySetName (Key * key, const char * newName)
 }
 
 /**
- * @brief Add an already escaped name to the keyname.
+ * Add an already escaped name part to the Key's name.
  *
  * The same way as in keySetName() this method finds the canonical pathname:
  * - it will ignore /./
@@ -498,7 +537,7 @@ ssize_t keySetName (Key * key, const char * newName)
  * @snippet keyName.c add name
  *
  * Unlike keySetName() it adds relative to the previous name and
- * cannot change the namespace of a key.
+ * cannot change the namespace of a Key.
  * For example:
  * @snippet keyName.c namespace
  *
@@ -507,17 +546,20 @@ ssize_t keySetName (Key * key, const char * newName)
  * - be empty
  * - end with unequal number of \\
  *
- * @param key the key where a name should be added
- * @param newName the new name to append
- *
  * @pre @p key MUST be a valid #Key
  *
- * @since 0.8.11
+ * @param key the Key where a name should be added
+ * @param newName the new name to add to the name of @p key
  *
- * @retval -1 if `key == NULL`, @p key is read-only, `newName == NULL` or @p newName is not a valid escaped name
  * @returns new size of the escaped name of @p key
+ * @retval -1 if `key == NULL` or `newName == NULL`
+ * @retval -1 @p newName is not a valid escaped name
+ * @retval -1 @p key is read-only
  *
+ * @since 1.0.0
  * @ingroup keyname
+ * @see keySetName() for setting a Key's name
+ * @see keyAddBaseName() for adding a basename to a Key
  */
 ssize_t keyAddName (Key * key, const char * newName)
 {
@@ -652,10 +694,10 @@ int keyReplacePrefix (Key * key, const Key * oldPrefix, const Key * newPrefix)
 			elektraFree (key->ukey);
 		}
 
-		key->key = elektraStrNDup (newPrefix->key, newPrefix->keySize);
+		key->key = elektraMemDup (newPrefix->key, newPrefix->keySize);
 		key->keySize = newPrefix->keySize;
 
-		key->ukey = elektraStrNDup (newPrefix->ukey, newPrefix->keyUSize);
+		key->ukey = elektraMemDup (newPrefix->ukey, newPrefix->keyUSize);
 		key->keyUSize = newPrefix->keyUSize;
 		return 1;
 	}
@@ -1186,33 +1228,37 @@ void elektraKeyNameUnescape (const char * canonicalName, char * unescapedName)
 }
 
 /**
- * @brief Returns a pointer to the internal unescaped key name where the @p basename starts.
+ * Returns a pointer to the unescaped Key's name where the basename starts.
  *
  * This is a much more efficient version of keyGetBaseName() and you should
  * use it if you are responsible enough to not mess up things. The name might
  * change or even point to a wrong place after a keySetName(). So make
  * sure to copy the memory before the name changes.
  *
- * keyBaseName() returns "" when there is no keyBaseName. The reason is
+ * keyBaseName() returns "" when the Key has no basename. The reason is
  * @snippet testabi_key.c base0 empty
  *
- * And there is also support for really empty basenames:
+ * There is also support for really empty basenames:
  * @snippet testabi_key.c base1 empty
  *
  * @note You must never use the pointer returned by keyBaseName()
- * method to change the name, but you should use keySetBaseName()
+ * method to change the name. You should use keySetBaseName()
  * instead.
  *
  * @note Do not assume that keyBaseName() points to the same region as
  * keyName() does.
  *
- * @param key the object to obtain the basename from
- * @return a pointer to the basename
- * @retval "" when the key has no (base)name
+ * @param key the Key to obtain the basename from
+ *
+ * @return a pointer to the Key's basename
+ * @retval "" when the Key has no (base)name
  * @retval 0 on NULL pointer
- * @see keyGetBaseName(), keyGetBaseNameSize()
- * @see keyName() to get a pointer to the name
+ *
+ * @since 1.0.0
  * @ingroup keyname
+ * @see keyGetBaseName() for getting a copy of the Key's basename
+ * @see keyGetBaseNameSize() for getting the size of the Key's basename
+ * @see keyName() for getting a pointer to the Key's name
  */
 const char * keyBaseName (const Key * key)
 {
@@ -1229,21 +1275,28 @@ const char * keyBaseName (const Key * key)
 
 
 /**
- * Calculates number of bytes needed to store basename of @p key.
+ * Calculates number of bytes needed to store basename of @p key (including
+ * NULL terminator).
  *
- * Key names that have only root names (e.g. @c "system:/" or @c "user:/"
- * or @c "user:domain" ) does not have basenames, thus the function will
- * return 1 bytes to store "".
+ * Key names consisting of only root names (e.g. @c "system:/" or @c "user:/"
+ * or @c "user:domain" ) do not have basenames. In this case the function will
+ * return 1, because only a NULL terminator is needed for storage.
  *
  * Basenames are denoted as:
  * - @c system:/some/thing/basename -> @c basename
  * - @c user:domain/some/thing/base\\/name > @c base\\/name
  *
- * @param key the key object to work with
- * @return size in bytes of @p key's basename including ending NULL
- * @see keyBaseName(), keyGetBaseName()
- * @see keyName(), keyGetName(), keySetName()
+ * @param key the Key to get the size of the basename from
+ *
+ * @return size in bytes of the Key's basename including NULL terminator
+ * @retval -1 if the Key's basename is NULL
+ *
+ * @since 1.0.0
  * @ingroup keyname
+ * @see keyBaseName() for getting a pointer to a Key's basename
+ * @see keyGetBaseName() for getting a copy of a Key's basename
+ * @see keyName(), keyGetName() for getting a pointer / copy of the whole name
+ * @see keySetName() for setting a Key's name
  */
 ssize_t keyGetBaseNameSize (const Key * key)
 {
@@ -1255,23 +1308,32 @@ ssize_t keyGetBaseNameSize (const Key * key)
 
 
 /**
- * Calculate the basename of a key name and put it in @p returned finalizing
- * the string with NULL.
+ * Copy the Key's basename to @p returned
+ *
+ * The copy will include a NULL terminator which will be considered for the
+ * returned size. Nothing will be copied if @p maxSize is smaller than the size
+ * of the basename.
  *
  * Some examples:
  * - basename of @c system:/some/keyname is @c keyname
  * - basename of @c "user:/tmp/some key" is @c "some key"
  *
- * @param key the key to extract basename from
- * @param returned a pre-allocated buffer to store the basename
- * @param maxSize size of the @p returned buffer
+ * @param key the Key to extract basename from
+ * @param returned a pre-allocated buffer for storing the basename
+ * @param maxSize size of the buffer @p returned
+ *
  * @return number of bytes copied to @p returned
- * @retval 1 on empty name
+ * @retval 1 when Key's name is empty
  * @retval -1 on NULL pointers
  * @retval -1 when maxSize is 0 or larger than SSIZE_MAX
- * @see keyBaseName(), keyGetBaseNameSize()
- * @see keyName(), keyGetName(), keySetName()
+ * @retval -1 when maxSize is smaller than the size of the Key's basename
+ *
+ * @since 1.0.0
  * @ingroup keyname
+ * @see keyBaseName() for getting a pointer to the Key's basename
+ * @see keyGetBaseNameSize() for getting the size of a Key's basename
+ * @see keyName(), keyGetName() for getting a pointer / copy of the whole name
+ * @see keySetName() for setting a Key's name
  */
 ssize_t keyGetBaseName (const Key * key, char * returned, size_t maxSize)
 {
@@ -1506,19 +1568,19 @@ static size_t keyAddBaseNameInternal (Key * key, const char * baseName)
 }
 
 /**
- * Adds @p baseName (that will be escaped) to the current key name.
+ * Adds @p baseName to the name of @p key.
  *
- * A new baseName will be added, no other part of the key name will be
- * affected.
+ * @p baseName will be escaped before adding it to the name of @p key.
+ * No other part of the Key's name will be affected.
  *
  * Assumes that @p key is a directory and will append @p baseName to it.
  * The function adds the path separator for concatenating.
  *
- * So if @p key has name @c "system:/dir1/dir2" and this method is called with
+ * If @p key has the name @c "system:/dir1/dir2" and this method is called with
  * @p baseName @c "mykey", the resulting key will have the name
  * @c "system:/dir1/dir2/mykey".
  *
- * When @p baseName is 0 nothing will happen and the size of the name is returned.
+ * When @p baseName is 0, nothing will happen and the size of the name is returned.
  *
  * The escaping rules apply as in @link keyname above @endlink.
  *
@@ -1528,17 +1590,20 @@ static size_t keyAddBaseNameInternal (Key * key, const char * baseName)
  * E.g. if you add . it will be escaped:
  * @snippet testabi_key.c base1 add
  *
- * @see keySetBaseName() to set a base name
- * @see keySetName() to set a new name.
+ * @param key the Key to add the basename to
+ * @param baseName the string to append to the Key's name
  *
- * @param key the key object to work with
- * @param baseName the string to append to the name
- * @return the size in bytes of the new key name including the ending NULL
- * @retval -1 if the key had no name
+ * @return the size in bytes of the Key's new name including the NULL terminator
+ * @retval -1 if the Key has no name
  * @retval -1 on NULL pointers
- * @retval -1 if key was inserted to a keyset before
- * @retval -1 on allocation errors
+ * @retval -1 if Key was inserted into KeySet before
+ * @retval -1 if the Key was read-only
+ * @retval -1 on memory allocation errors
+ *
+ * @since 1.0.0
  * @ingroup keyname
+ * @see keySetBaseName() for setting the basename of a Key
+ * @see keySetName() for setting the name of a key
  *
  */
 ssize_t keyAddBaseName (Key * key, const char * baseName)
@@ -1552,17 +1617,17 @@ ssize_t keyAddBaseName (Key * key, const char * baseName)
 }
 
 /**
- * Sets @c baseName as the new basename for @c key.
+ * Sets @p baseName as the new basename for @p key.
  *
- * Only the baseName will be affected and no other part of the key.
+ * Only the basename of the Key will be affected.
  *
  * A simple example is:
  * @snippet keyBasename.c set base basic
  *
- * All text after the last @c '/' in the @p key keyname is erased and
+ * All text after the last @c '/' in the Key's name is erased and
  * @p baseName is appended.
- * If @p baseName is 0 (NULL), then the last part of the keyname is
- * removed without replacement.
+ * If @p baseName is 0 (NULL), then the last part of the Key's name is
+ * removed without replacement. The root name of the Key will not be removed though.
  *
  * Let us suppose @p key has name @c "system:/dir1/dir2/key1". If @p baseName
  * is @c "key2", the resulting key name will be @c "system:/dir1/dir2/key2".
@@ -1580,23 +1645,24 @@ ssize_t keyAddBaseName (Key * key, const char * baseName)
  * (dot-dot), @c "%" (empty basename)). They will be properly escaped
  * and will not have their usual meaning.
  *
- * @see keyname for more details on special names
+ * If you want to add to the basename instead of changing it, use keyAddBaseName().
+ * If you do not want any escaping, use keyAddName().
  *
- * If you want to add and not change the basename, use keyAddBaseName()
- * instead. If you do not want escaping, use keyAddName() instead.
+ * @param key the Key whose basename to set
+ * @param baseName the new basename for the Key
  *
- * @see keyAddBaseName() to add a basename instead of changing it
- * @see keyAddName() to add a name without escaping
- * @see keySetName() to set a completely new name
- *
- *
- * @param key the key object to work with
- * @param baseName the string used to overwrite the basename of the key
  * @return the size in bytes of the new key name
- * @retval -1 on NULL pointers in key
- * @retval -1 if key was inserted to a keyset before
+ * @retval -1 on NULL pointers
+ * @retval -1 if Key was inserted into KeySet before
+ * @retval -1 if Key is read-only
  * @retval -1 on allocation errors
+ *
+ * @since 1.0.0
  * @ingroup keyname
+ * @see keyAddBaseName() for adding a basename instead of changing it
+ * @see keyAddName() for adding a name without escaping
+ * @see keySetName() for setting a completely new name
+ * @see keyname for more details on special names
  */
 ssize_t keySetBaseName (Key * key, const char * baseName)
 {
@@ -1631,25 +1697,28 @@ ssize_t keySetBaseName (Key * key, const char * baseName)
 }
 
 /**
- * For currently valid namespaces see #elektraNamespace.
+ * Returns the #elektraNamespace for a Key.
  *
- * To handle every possible cases (including namespaces) a key can have:
+ * To handle every namespace a Key could have, you can use the following snippet:
  * @snippet namespace.c namespace
  *
  * To loop over all valid namespaces use:
  * @snippet namespace.c loop
  *
- * @note This method might be enhanced. You do not have any guarantee
- * that, when for a specific name #KEY_NS_META
- * is returned today, that it still will be returned after the next
- * recompilation. So make sure that your compiler gives you a warning
+ * @note This method might be extended. There is no guarantee that a Key with
+ * a specific namespace will retain that namespace after recompilation.
+ * Make sure that your compiler gives you a warning
  * for unhandled switches (gcc: -Wswitch or -Wswitch-enum if you
- * want to handle default) and look out for those warnings.
+ * want to handle default) and look out for those warnings when recompiling.
  *
- * @param key the key object to work with
- * @return the namespace of a key.
+ * @param key the Key to get the namespace from
  *
+ * @return the namespace of the Key
+ * @retval KEY_NS_NONE if Key is NULL
+ *
+ * @since 1.0.0
  * @ingroup keyname
+ * @see keySetNamespace() for setting a Key's namespace
  */
 elektraNamespace keyGetNamespace (const Key * key)
 {
@@ -1658,18 +1727,22 @@ elektraNamespace keyGetNamespace (const Key * key)
 }
 
 /**
- * Changes the namespace of a key. The rest of the name remains unchanged.
+ * Changes the namespace of a Key.
  *
- * @param key The #Key whose namespace will be changed
- * @param ns  The new namespace of for @p key
+ * The rest of the Key's name remains unchanged.
  *
  * @pre @p ns MUST be a valid namespace and not #KEY_NS_NONE
  * @pre @p key MUST be a valid #Key, especially `key != NULL`
  *
- * @retval -1 precondition error
- * @returns the new size the @p{key}'s escaped name
+ * @param key The #Key whose namespace will be changed
+ * @param ns  The new namespace of for @p key
  *
+ * @return the new size in bytes of the Key's namespace
+ * @retval -1 precondition error
+ *
+ * @since 1.0.0
  * @ingroup keyname
+ * @see keyGetNamespace() for getting a Key's namespace
  */
 ssize_t keySetNamespace (Key * key, elektraNamespace ns)
 {
