@@ -16,6 +16,6 @@
 int elektraMathcheckGet (Plugin * handle, KeySet * ks, Key * parentKey);
 int elektraMathcheckSet (Plugin * handle, KeySet * ks, Key * parentKey);
 
-Plugin * ELEKTRA_PLUGIN_EXPORT (mathcheck);
+Plugin * ELEKTRA_PLUGIN_EXPORT;
 
 #endif
