@@ -10,6 +10,8 @@ ROOT=$USER_ROOT
 FILE="$(mktempfile_elektra)"
 SIDE=$ROOT/../side_val
 
+RAN_ONCE=0
+
 cleanup() {
 	rm -f $FILE
 }
@@ -20,12 +22,17 @@ exit_if_fail "For export/import /dev must be mounted"
 [ -e /dev/stdout ]
 exit_if_fail "For export/import /dev must be mounted"
 
+"$KDB" rm -r $ROOT
+"$KDB" rm $SIDE
+
 for PLUGIN in $PLUGINS; do
 	if is_not_rw_storage; then
 		echo "-- $PLUGIN not a read-write storage"
 		continue
 	fi
 
+	RAN_ONCE=1
+
 	echo -------- $PLUGIN -----------
 
 	echo "Import with existing root"
@@ -41,14 +48,16 @@ for PLUGIN in $PLUGINS; do
 	test "x$("$KDB" ls $ROOT)" = "x$ROOT"
 	succeed_if "Root key not found"
 
-	"$KDB" import $ROOT $PLUGIN < "$DATADIR"/one_value.$PLUGIN
+	"$KDB" import $ROOT $PLUGIN "$DATADIR"/one_value.$PLUGIN
 	succeed_if "Could not run kdb import"
 
-	test "x$("$KDB" ls $ROOT)" = "xuser/tests/script"
+	test "x$("$KDB" ls $ROOT)" = "xuser:/tests/script"
 	succeed_if "key name not correct one_value"
 
-	test "$("$KDB" get $ROOT)" = root
-	succeed_if "root value not correct"
+	if [ "x$PLUGIN" != "xyajl" ]; then
+		test "$("$KDB" get $ROOT)" = root
+		succeed_if "root value not correct"
+	fi
 
 	"$KDB" export $ROOT $PLUGIN > $FILE
 	succeed_if "Could not run kdb export"
@@ -61,10 +70,10 @@ for PLUGIN in $PLUGINS; do
 
 	echo "Import with empty root"
 
-	"$KDB" import $ROOT $PLUGIN < "$DATADIR"/one_value.$PLUGIN
+	"$KDB" import $ROOT $PLUGIN "$DATADIR"/one_value.$PLUGIN
 	succeed_if "Could not run kdb import"
 
-	test "x$("$KDB" ls $ROOT)" = "xuser/tests/script"
+	test "x$("$KDB" ls $ROOT)" = "xuser:/tests/script"
 	succeed_if "key name not correct one_value empty root"
 
 	if [ "x$PLUGIN" != "xyajl" ]; then
@@ -83,30 +92,32 @@ for PLUGIN in $PLUGINS; do
 	"$KDB" rm -r $ROOT
 	succeed_if "Could not remove root"
 
-	echo "Import as stream (using cat)"
+	if [ "x$PLUGIN" != "xdini" ]; then
+		echo "Import as stream (using cat)"
 
-	cat "$DATADIR"/one_value.$PLUGIN | "$KDB" import $ROOT $PLUGIN
-	succeed_if "Could not run kdb import"
+		cat "$DATADIR"/one_value.$PLUGIN | "$KDB" import $ROOT $PLUGIN
+		succeed_if "Could not run kdb import"
 
-	test "x$("$KDB" ls $ROOT)" = "xuser/tests/script"
-	succeed_if "key name not correct one_value empty root"
+		test "x$("$KDB" ls $ROOT)" = "xuser:/tests/script"
+		succeed_if "key name not correct one_value empty root"
 
-	if [ "x$PLUGIN" != "xyajl" ]; then
-		#TODO: yajl currently cannot hold values within
-		#directories, do not hardcode that
-		test "$("$KDB" get $ROOT)" = root
-		succeed_if "root value not correct"
+		if [ "x$PLUGIN" != "xyajl" ]; then
+			#TODO: yajl currently cannot hold values within
+			#directories, do not hardcode that
+			test "$("$KDB" get $ROOT)" = root
+			succeed_if "root value not correct"
+		fi
+
+		"$KDB" export $ROOT $PLUGIN > $FILE
+		succeed_if "Could not run kdb export"
+
+		diff "$DATADIR"/one_value.$PLUGIN $FILE
+		succeed_if "Export file one_value.$PLUGIN was not equal"
+
+		"$KDB" rm -r $ROOT
+		succeed_if "Could not remove root"
 	fi
 
-	"$KDB" export $ROOT $PLUGIN > $FILE
-	succeed_if "Could not run kdb export"
-
-	diff "$DATADIR"/one_value.$PLUGIN $FILE
-	succeed_if "Export file one_value.$PLUGIN was not equal"
-
-	"$KDB" rm -r $ROOT
-	succeed_if "Could not remove root"
-
 	echo "Import with wrong root (overwrite)"
 
 	"$KDB" set $SIDE val
@@ -115,10 +126,10 @@ for PLUGIN in $PLUGINS; do
 	"$KDB" set $ROOT "wrong_root" > /dev/null
 	exit_if_fail "could not set wrong_root"
 
-	"$KDB" import -s "import" $ROOT $PLUGIN < "$DATADIR"/one_value.$PLUGIN
+	"$KDB" import -s "import" $ROOT $PLUGIN "$DATADIR"/one_value.$PLUGIN
 	succeed_if "Could not run kdb import"
 
-	test "x$("$KDB" ls $ROOT)" = "xuser/tests/script"
+	test "x$("$KDB" ls $ROOT)" = "xuser:/tests/script"
 	succeed_if "key name not correct"
 
 	if [ "x$PLUGIN" != "xyajl" ]; then
@@ -152,11 +163,11 @@ for PLUGIN in $PLUGINS; do
 	"$KDB" import $ROOT $PLUGIN < "$DATADIR"/two_value.$PLUGIN
 	succeed_if "Could not run kdb import"
 
-	test "x$("$KDB" ls $ROOT)" = "xuser/tests/script
-user/tests/script/key"
-	succeed_if "key name not correct"
-
 	if [ "x$PLUGIN" != "xyajl" ]; then
+		test "x$("$KDB" ls $ROOT)" = "xuser:/tests/script
+user:/tests/script/key"
+		succeed_if "key name not correct"
+
 		#TODO: yajl currently cannot hold values within
 		#directories, do not hardcode that
 		test "$("$KDB" get $ROOT)" = root
@@ -177,10 +188,10 @@ user/tests/script/key"
 	"$KDB" set $SIDE val
 	succeed_if "Could not set $SIDE"
 
-	"$KDB" import -s "cut" $ROOT $PLUGIN < "$DATADIR"/one_value.$PLUGIN
+	"$KDB" import -s "cut" $ROOT $PLUGIN "$DATADIR"/one_value.$PLUGIN
 	succeed_if "Could not run kdb import"
 
-	test "x$("$KDB" ls $ROOT)" = "xuser/tests/script"
+	test "x$("$KDB" ls $ROOT)" = "xuser:/tests/script"
 	succeed_if "key name not correct"
 
 	if [ "x$PLUGIN" != "xyajl" ]; then
@@ -213,10 +224,10 @@ user/tests/script/key"
 	"$KDB" set $SIDE val
 	succeed_if "Could not set $SIDE"
 
-	"$KDB" import -s "cut" $ROOT $PLUGIN < "$DATADIR"/one_value.$PLUGIN
+	"$KDB" import -s "cut" $ROOT $PLUGIN "$DATADIR"/one_value.$PLUGIN
 	succeed_if "Could not run kdb import"
 
-	test "x$("$KDB" ls $ROOT)" = "xuser/tests/script"
+	test "x$("$KDB" ls $ROOT)" = "xuser:/tests/script"
 	succeed_if "key name not correct"
 
 	if [ "x$PLUGIN" != "xyajl" ]; then
@@ -247,4 +258,7 @@ user/tests/script/key"
 
 done
 
+test $RAN_ONCE != 0
+succeed_if "check_import should run for at least one plugin"
+
 end_script
